package eu.ztsh.garmin.mapbox

import com.mapbox.api.directions.v5.models.DirectionsRoute
import com.mapbox.navigation.core.MapboxNavigation
import eu.ztsh.garmin.MainActivity
import eu.ztsh.garmin.mock.ReplayResources

class TripControl(private val mapControl: MapControl, private val tripMode: TripMode) {

    val replay = ReplayResources(mapControl)

    fun onAttached(mapboxNavigation: MapboxNavigation) {
        when (tripMode) {
            TripMode.REPLAY -> replay.onAttached(mapboxNavigation)
            TripMode.GPS -> startSession(mapboxNavigation)
        }
    }

    fun onDetached(mapboxNavigation: MapboxNavigation) {
        when (tripMode) {
            TripMode.REPLAY -> replay.onDetached(mapboxNavigation)
            TripMode.GPS -> stopSession(mapboxNavigation)
        }
    }

    fun initLocation() {
        if (tripMode == TripMode.REPLAY) {
            replay.replayOriginLocation()
        }
    }

    fun startSession(mapboxNavigation: MapboxNavigation) {
        if (tripMode == TripMode.GPS) {
            (mapControl.context as MainActivity).permissionsHelper.checkPermissions {
                mapboxNavigation.startTripSession()
            }
        }
    }

    fun startSession(directionsRoute: DirectionsRoute) {
        if (tripMode == TripMode.REPLAY) {
            replay.startSimulation(directionsRoute)
        }
    }

    fun stopSession() {
        if (tripMode == TripMode.REPLAY) {
            replay.stopSimulation()
        }
    }

    fun stopSession(mapboxNavigation: MapboxNavigation) {
        if (tripMode == TripMode.GPS) {
            mapboxNavigation.stopTripSession()
        }
    }

}

enum class TripMode {
    GPS,
    REPLAY
}
